<template>
  <div class="p-3 pb-5 mb-5">
    <!-- بخش موجودی کیف پول -->
    <div class="row g-4 mb-4">
      <!-- کارت موجودی -->
      <div class="col-lg-6">
        <div class="card border-0 shadow-sm rounded-4 h-100">
          <div class="card-body p-4">
            <div class="d-flex align-items-center justify-content-between mb-4">
              <h5 class="mb-0 fw-bold text-default">
                <i class="fas fa-wallet ms-2"></i>
                {{ t("account.referral.title") }}
              </h5>
            </div>

            <!-- دایره موجودی -->
            <div class="text-center my-3 my-md-4">
              <div class="position-relative d-inline-block">
                <div class="wallet-circle warning p-3 p-md-4 rounded-circle d-flex align-items-center justify-content-center">
                  <div>
                    <div class="fs-6 text-muted mb-2">{{ t("account.referral.balance") }}</div>
                    <div class="fw-bold" style="font-size: clamp(1.5rem, 4.5vw, 1rem);">
                      {{ data.referral.balance }} <i class="icon icon-filled-coins text-default"></i>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            <div class="fw-bold font-size-20 text-center d-flex align-items-center justify-content-center flex-column" @click="shareLink">
              <span class="mx-2 font-size-18 mb-2">
                <i class="icon icon-filled-share font-size-18"></i>
                {{ t('account.referral.invite_code') }}
              </span>

              <canvas id="my-canvas" width="200" height="200"></canvas>

              <button type="button" class="mx-2 mb-2 btn btn-sm btn-outline-default font-size-14">https://artjoo.com/invite/{{ auth?.user?.id }}</button>
            </div>

            <hr class="my-4 border-2 opacity-10">

            <!-- فرم شارژ کیف پول -->
            <div>
              <h6 class="fw-bold mb-3 text-default">
                <i class="fas fa-plus-circle me-2"></i>
                {{ t("account.referral.charge_section.title") }}
              </h6>
              <p class="mb-3 text-dark font-size-15">
                <i class="fas fa-plus-circle font-size-13 me-2"></i>
                {{ t("account.referral.charge_section.description") }}
              </p>

              <ul class="list-group p-0">
                <li class="list-group-item shadow-sm my-1 rounded p-1 d-flex align-items-center justify-content-between font-size-12">
                  <span class="w-70-px d-flex align-items-center justify-content-start"> <i class="icon icon-filled-coins text-default mx-1"></i> 5000 </span>
                  <span class="w-200-px">{{ t('account.referral.rewards.in_app_credit', { amount: '200,000' }) }}</span>
                </li>
                <li class="list-group-item shadow-sm my-1 rounded p-1 d-flex align-items-center justify-content-between font-size-12">
                  <span class="w-70-px d-flex align-items-center justify-content-start"><i class="icon icon-filled-coins text-default mx-1"></i> 1000 </span>
                  <span class="w-200-px">{{ t('account.referral.rewards.lottery_phone') }}</span>
                </li>
                <li class="list-group-item shadow-sm my-1 rounded p-1 d-flex align-items-center justify-content-between font-size-12">
                  <span class="w-70-px d-flex align-items-center justify-content-start"> <i class="icon icon-filled-coins text-default mx-1"></i> 30000 </span>
                  <span class="w-200-px">{{ t('account.referral.rewards.lottery_cash') }}</span>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>

</template>

<script setup>
import {useI18n} from 'vue-i18n';
import {ref, computed, onMounted, reactive} from 'vue';
import {useAuthStore} from '~/stores/auth';
import qrCodeWithLogo from 'qr-code-with-logo'

onMounted(() => {
  qrCodeWithLogo.toCanvas({
    canvas: document.getElementById('my-canvas'),
    content: 'https://artjoo.com/invite/' + auth?.user?.id,
    logo: {
      src: '/logo.png'
    }
  })
})

definePageMeta({
  layout: "default",
  middleware: ['auth']
})

// Variable
const {t} = useI18n();
const {$api,$sweetalert, $helper} = useNuxtApp();
const auth = useAuthStore();

// Data
const data = reactive({
  payment_loaded: false,
  loaded: false,
  showPayment: false,
  amount: "",
  referral: {
    balance: '0',
  },
  url: "",
});

const copyAdLink = async () => {
  try {
    const adLink = 'https://artjoo.com/invite/' + auth.user.id;
    await navigator.clipboard.writeText(adLink);
    $sweetalert.success(t("advertise_page.share_success"));
  } catch (error) {
    $sweetalert.error(t("advertise_page.share_error"));
    console.error("Error copying link:", error);
  }
};

const shareLink = async () => {
  const inviteUrl = 'https://artjoo.com/invite/' + auth.user.id;
  const title = 'لینک دعوت آرت جو';
  const text = 'آرت جو اولین و تنها هوش مشتری یاب ایران';

  // ✅ اگر WebView اندروید هست
  if (window.Android?.shareContent) {
    try {
      window.Android.shareContent(title, text, inviteUrl);
    } catch (error) {
      console.error("Android share error:", error);
      await copyAdLink();
    }
    return;
  }

  // ✅ اگر Web Share API در مرورگر پشتیبانی می‌شود
  if (navigator.share) {
    try {
      await navigator.share({ title, text, url: inviteUrl });
    } catch (error) {
      console.error("Web share error:", error);
      await copyAdLink(); // اگر کاربر Cancel کرد یا خطا رخ داد
    }
    return;
  }

  // ✅ در نهایت: کپی لینک به کلیپ‌بورد
  await copyAdLink();
};

// Actions
const getData = async () => {
  await $api.post('/user/referral', {}).then((value) => {
    if (value.data.status) {
      data.referral = value.data.data;

      setTimeout(() => {
        data.loaded = true;
      }, 500)
    }
  })
};

// Life Cycle
onMounted(() => {
  getData();
});

</script>

<style scoped>

</style>